import React from 'react';
import { formatMessage, setLocale, getLocale } from 'umi-plugin-react/locale';
import { Menu, Icon } from 'antd';
import { ClickParam } from 'antd/es/menu';
import classNames from 'classnames';
import HeaderDropdown from '../HeaderDropdown';
import styles from './index.less';
interface localesProps {
  label: string;
  key: string;
  icon: string;
}

interface SelectLangProps {
  className?: string;
  locales?: Array<localesProps>;
}

const SelectLang: React.FC<SelectLangProps> = props => {
  const { className, locales } = props;
  // 获取当前语言
  const selectedLang = getLocale();
  const changeLang = ({ key }: ClickParam) => setLocale(key, false);
  const langMenu = (
    <Menu className={styles.menu} selectedKeys={[selectedLang]} onClick={changeLang}>
      {locales &&
        locales.map(({ label, key, icon }) => (
          <Menu.Item key={key}>
            <span role="img" aria-label={label}>
              {icon}
            </span>{' '}
            {label}
          </Menu.Item>
        ))}
    </Menu>
  );
  return (
    <HeaderDropdown overlay={langMenu} placement="bottomRight">
      <span className={classNames(styles.dropDown, className)}>
        <Icon type="global" title={formatMessage({ id: 'navBar.lang' })} />
      </span>
    </HeaderDropdown>
  );
};

export default SelectLang;
